@@ -1,14 +1,14 @@
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 from .env_io import EnvIO
 from .file_io import FileIO
 from .stopwatch import Stopwatch
 from .base_object import BaseObject
 from .common_utils import prov_stack
-from .common_utils import get_ontology_name
 from .common_utils import odds_of
 from .enforce_type import Enforcer
 from .text_utils import TextUtils
 from .text_matcher import TextMatcher
 from .crypto_base import CryptoBase
 from .service_event_generator import ServiceEventGenerator
+from .time_helper import TimeHelper
