@@ -18,7 +18,7 @@ class BaseObject(object):
         """
         Created:
             29-Sept-2021
-            craig@grafflr.ai
+            craigtrim@gmail.com
         :param component_name:
             the component name
         """
