@@ -2,7 +2,10 @@
 # -*- coding: UTF-8 -*-
 """ Text Utility Methods: Common Functions without Special Libraries """
 
+
+from os import sep
 from statistics import mean
+from unicodedata import category
 
 STOPWORDS = [
     'a',
@@ -26,6 +29,21 @@ STOPWORDS = [
 class TextUtils(object):
     """ Text Utility Methods: Common Functions without Special Libraries """
 
+    @staticmethod
+    def is_punctuation(char):
+        """Checks whether `char` is a punctuation character."""
+        cp = ord(char)
+        # We treat all non-letter/number ASCII as punctuation.
+        # Characters such as "^", "$", and "`" are not in the Unicode
+        # Punctuation class but we treat them as punctuation anyways, for
+        # consistency.
+        if (cp >= 33 and cp <= 47) or (cp >= 58 and cp <= 64) or (cp >= 91 and cp <= 96) or (cp >= 123 and cp <= 126):
+            return True
+        cat = category(char)
+        if cat.startswith("P"):
+            return True
+        return False
+
     @staticmethod
     def find_subsumed_tokens(tokens: list) -> list:
         """ Find Subsumed Tokens (if any)
@@ -178,7 +196,7 @@ class TextUtils(object):
         if len(buffer):
             master.append(' '.join(buffer).strip())
 
-        return "\\n".join(master).strip()
+        return sep.join(master).strip()
 
     @staticmethod
     def ends_with_punctuation(input_text: str) -> bool:
